============================================================================
Discrete Model
============================================================================

***************************************
Implementation of the discrete model for TotemBionet
***************************************

.. image:: https://travis-matrix-badges.herokuapp.com/repos/clement-alexandre/TotemBionet/branches/master/3
    :target: https://travis-ci.com/clement-alexandre/TotemBionet


Installation
---------------

Install with `pip <https://pypi.org/project/discrete-model/>`_:

    `pip install discrete-model`

Install with `conda <https://anaconda.org/alexandre-clement/discrete-model>`_:

    `conda install -c alexandre-clement discrete-model`


Run tests
---------

Execute the following command to run the test suite:
    
    `python -m unittest tests.test`
